@@ -1,7 +1,7 @@
 package Test::Rinci;
 
-our $DATE = '2016-02-17'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2016-02-21'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -103,10 +103,13 @@ sub _test_function_metadata {
                     $Test->is_num($r->[0], $eg->{status} // 200, "status")
                         or do { $Test->diag($Test->explain($r)); $ok = 0 };
                     if (exists $eg->{result}) {
-                        Test::More::is_deeply($r, $eg->{result}, "result")
+                        my $actual_r = $meta->{_orig_result_naked} ?
+                            $r->[2] : $r;
+                        Test::More::is_deeply(
+                            $actual_r, $eg->{result}, "result")
                               or do {
                                   Test::More::diag(
-                                      Test::More::explain($r));
+                                      Test::More::explain($actual_r));
                                   $ok = 0;
                               };
                     }
@@ -318,7 +321,7 @@ Test::Rinci - Test Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.12 of Test::Rinci (from Perl distribution Test-Rinci), released on 2016-02-17.
+This document describes version 0.13 of Test::Rinci (from Perl distribution Test-Rinci), released on 2016-02-21.
 
 =head1 SYNOPSIS
 
@@ -416,7 +419,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Test-Rinci
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Test-Rinci>.
+Source repository is at L<https://github.com/sharyanto/perl-Test-Rinci>.
 
 =head1 BUGS
 
